==> 1.1.0.tar.gz: lib/models/base_model.dart <==
part of tecfy_basic_package;

abstract class BaseModel {
  /// return the id valie
  String get idValue;

  /// return display name
  String get displayName;

  /// return bool from dynamic
  bool getBool(dynamic val) => BaseModel.getBoolEx(val);

  /// return bool from dynamic
  static bool getBoolEx(dynamic val) {
    if (val == null) return false;
    if (val is bool) return val;
    if (val is String) return val == 'true' || val == '1';
    if (val is num) return val == 1;
    return false;
  }

  /// return DateTime from dynamic
  DateTime? getDate(dynamic val) => BaseModel.getDateEx(val);

  /// return DateTime from dynamic
  static DateTime? getDateEx(dynamic val) {
    if (val == null) return null;
    if (val is DateTime) return val;
    if (val is String) return parseUTC(val);
    return null;
  }

  /// return double from dynamic
  double? getDouble(dynamic val, [bool defaultIsZero = true]) =>
      BaseModel.getDoubleEx(val, defaultIsZero);

  /// return double from dynamic
  static double? getDoubleEx(dynamic val, [bool defaultIsZero = true]) {
    if (val == null) return defaultIsZero ? 0 : null;
    if (val is num) return val.toDouble();
    if (val is String)
      return double.tryParse(val) ?? (defaultIsZero ? 0 : null);
    return (defaultIsZero ? 0 : null);
  }

  /// return true if the Id is default
  static bool isDefault(String? id) => id != null && id.length < 30;

  /// convert service time to DateTime UTC
  static DateTime? parseUTC(String? serverValue,
      {String format = "yyyy-MM-ddTHH:mm:ss", DateTime? defaultValue}) {
    if (serverValue == null) return defaultValue;
    try {
      return intl.DateFormat(format).parseUTC(serverValue);
    } catch (err) {
      return defaultValue;
    }
  }
}

==> 1.1.23.tar.gz: lib/models/base_model.dart <==
part of tecfy_basic_package;

abstract class BaseModel {
  /// return the id valie
  String get idValue;

  /// return display name
  String get displayName;

  /// return bool from dynamic
  bool getBool(dynamic val) => BaseModel.getBoolEx(val);

  /// return bool from dynamic
  static bool getBoolEx(dynamic val) {
    if (val == null) return false;
    if (val is bool) return val;
    if (val is String) return val == 'true' || val == '1';
    if (val is num) return val == 1;
    return false;
  }

  /// return DateTime from dynamic
  DateTime? getDate(dynamic val) => BaseModel.getDateEx(val);

  /// return DateTime from dynamic
  static DateTime? getDateEx(dynamic val) {
    if (val == null) return null;
    if (val is DateTime) return val;
    if (val is String) return parseUTC(val);
    return null;
  }

  /// return double from dynamic
  double? getDouble(dynamic val, [bool defaultIsZero = true]) =>
      BaseModel.getDoubleEx(val, defaultIsZero);

  /// return int from dynamic
  int? getInt(dynamic val, [bool defaultIsZero = true]) =>
      BaseModel.getIntEx(val, defaultIsZero);

  /// return double from dynamic
  static double? getDoubleEx(dynamic val, [bool defaultIsZero = true]) {
    if (val == null) return defaultIsZero ? 0 : null;
    if (val is num) return val.toDouble();
    if (val is String)
      return num.tryParse(val)?.toDouble() ?? (defaultIsZero ? 0 : null);
    return (defaultIsZero ? 0 : null);
  }

  /// return int from dynamic
  static int? getIntEx(dynamic val, [bool defaultIsZero = true]) {
    if (val == null || (val is num && val.isNaN))
      return defaultIsZero ? 0 : null;
    if (val is num) return val.toInt();
    if (val is String)
      return num.tryParse(val)?.toInt() ?? (defaultIsZero ? 0 : null);
    return (defaultIsZero ? 0 : null);
  }

  /// return true if the Id is default
  static bool isDefault(String? id) => id != null && id.length < 30;

  /// convert service time to DateTime UTC
  static DateTime? parseUTC(String? serverValue,
      {String format = "yyyy-MM-ddTHH:mm:ss", DateTime? defaultValue}) {
    if (serverValue == null) return defaultValue;
    try {
      return intl.DateFormat(format).parseUTC(serverValue);
    } catch (err) {
      return defaultValue;
    }
  }
}
